@@ -60,7 +60,7 @@ def main(arguments: dict = {}) -> None:
         report_name,
         report_author,
         university_name,
-        university_school,
+        university_school
     )
     logger.info(f"Report Complete: {report_name}.pdf")
 
